black property

Text get black

Returns a new Text widget with a Black color applied.

This getter creates a copy of the current Text widget with a black color.

Implementation

Text get black => color(FxColor.black);