neutral900 property

Text get neutral900

Returns a new Text widget with the Neutral 900 color applied.

This getter creates a copy of the current Text widget with the neutral 900 color from FxColor.

Implementation

Text get neutral900 => color(FxColor.neutral900);