leftStrong property
Provides a configuration for a stronger shadow pointing to the left.
Returns a list containing a single BoxShadow with a stronger shadow effect to the left.
Implementation
static List<BoxShadow> get leftStrong => _createShadow(
color: FxColor.dark.withValues(alpha: 0.25),
blurRadius: 12.0,
offset: const Offset(-8.0, 0.0),
spreadRadius: 1.0,
);