kcDark property
Text
get
kcDark
Returns a new Text widget with the Dark color applied.
This getter creates a copy of the current Text widget with the dark color from FxColor.
Implementation
Text get kcDark => color(FxColor.dark);