violet50 property
Text
get
violet50
Returns a new Text widget with the Violet 50 color applied.
This getter creates a copy of the current Text widget with the violet 50 color from FxColor.
Implementation
Text get violet50 => color(FxColor.violet50);