violet900 property
Text
get
violet900
Returns a new Text widget with the Violet 900 color applied.
This getter creates a copy of the current Text widget with the violet 900 color from FxColor.
Implementation
Text get violet900 => color(FxColor.violet900);